@@ -6,7 +6,7 @@ from aiohttp_rest_framework.fields import patch_marshmallow_fields
 from aiohttp_rest_framework.settings import Config, set_global_config
 from aiohttp_rest_framework.utils import create_connection  # noqa
 
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 APP_CONFIG_KEY = "rest_framework"
 
@@ -20,8 +20,7 @@ __all__ = (
 
 def setup_rest_framework(app: web.Application, conf: Mapping = None) -> None:
     user_settings = conf or {}
-    app_settings = Config(app, **user_settings)
-    app[APP_CONFIG_KEY] = app_settings
-
-    set_global_config(app_settings)
+    app_config = Config(app, **user_settings)
+    app[APP_CONFIG_KEY] = app_config
+    set_global_config(app_config)
     patch_marshmallow_fields()
