@@ -9,6 +9,7 @@ import sqlalchemy as sa
 from marshmallow.fields import *  # noqa
 from marshmallow.fields import __all__ as ma_fields_all  # noqa
 from psycopg2.extensions import PYINTERVAL
+from sqlalchemy import Table
 from sqlalchemy.dialects.postgresql import ARRAY, JSON
 from sqlalchemy.dialects.postgresql import UUID as PgUUID
 
@@ -213,22 +214,26 @@ class SAFieldBuilder(FieldBuilderABC):
         serializer=None,
         **kwargs
     ):
-        model: sa.Table = serializer.opts.model
-        column: sa.Column = model.columns.get(name)
+        model = serializer.opts.model
+        if isinstance(model, Table):
+            table = model
+        else:
+            table = model.__table__
+        column: sa.Column = table.columns.get(name)
         assert column is not None, (
             f"{name} was not found for {serializer.__class__.__name__} serializer "
-            f"in {model.name} model"
+            f"in {table.name} model"
         )
 
         mapping = ClassLookupDict(sa_ma_pg_field_mapping)
         field_cls = mapping.get(column.type, ma.fields.Inferred)
 
-        self._set_db_specific_kwargs(kwargs, column)
-        self._set_field_specific_kwargs(kwargs, field_cls, column)
+        self._set_db_specific_kwargs(column, kwargs)
+        self._set_field_specific_kwargs(column, kwargs, field_cls)
         field = field_cls(**kwargs)
         return field
 
-    def _set_db_specific_kwargs(self, kwargs: dict, column: sa.Column):
+    def _set_db_specific_kwargs(self, column: sa.Column, kwargs: dict) -> None:
         if column.nullable:
             kwargs.setdefault("allow_none", True)
             kwargs.setdefault("required", False)
@@ -248,7 +253,7 @@ class SAFieldBuilder(FieldBuilderABC):
         if column.server_default:
             kwargs.setdefault("required", False)
 
-    def _set_field_specific_kwargs(self, kwargs: dict, field_cls: typing.Type[ma.fields.Field], column: sa.Column):
+    def _set_field_specific_kwargs(self, column: sa.Column, kwargs: dict, field_cls: typing.Type[ma.fields.Field]):
         # for `Enum` we have to point which enum class is being used
         if issubclass(field_cls, Enum):
             kwargs["enum"] = column.type.enum_class
