@@ -1,28 +1,29 @@
 import asyncio
 import re
-import typing
+from typing import Awaitable, Callable, Optional
 
 from aiohttp import web
 
-from aiohttp_rest_framework.db.pg_sa import PGSAService
+from aiohttp_rest_framework.db.base import BaseDBManager
+from aiohttp_rest_framework.db.sa import SAManager
 from aiohttp_rest_framework.fields import SAFieldBuilder
 from aiohttp_rest_framework.types import DbOrmMapping
 from aiohttp_rest_framework.utils import get_model_fields_sa
 
 __all__ = (
-    "PG_SA",
+    "SA",
     "Config",
     "get_global_config",
     "set_global_config",
     "DEFAULT_APP_CONN_PROP",
 )
 
-PG_SA = "pg_sa"
-SCHEMA_TYPES = (PG_SA,)
+SA = "sa"
+SCHEMA_TYPES = (SA,)
 
 db_orm_mappings: DbOrmMapping = {
-    PG_SA: {
-        "service": PGSAService,
+    SA: {
+        "manager": SAManager,
         "field_builder": SAFieldBuilder,
         "model_fields_getter": get_model_fields_sa,
     },
@@ -38,9 +39,9 @@ class Config:
         app: web.Application,
         *,
         app_connection_property: str = DEFAULT_APP_CONN_PROP,
-        get_connection: typing.Callable[[], typing.Awaitable] = None,
-        db_service=None,
-        schema_type: str = PG_SA,
+        get_connection: Optional[Callable[[], Awaitable]] = None,
+        db_manager: Optional[BaseDBManager] = None,
+        schema_type: str = SA,
     ):
         assert isinstance(app_connection_property, str), (
             "`app_connection_property` has to be a string"
@@ -48,6 +49,7 @@ class Config:
         assert CONNECTION_PROP_RE.match(app_connection_property), (
             "`app_connection_property` must not have spaces and hyphens"
         )
+        self.app = app
         self.app_connection_property = app_connection_property
 
         assert schema_type in SCHEMA_TYPES, (
@@ -64,16 +66,17 @@ class Config:
             "`get_connection` has to be async callable"
         )
 
-        self.db_service_class = db_service or self._db_orm_mapping["service"]
+        self.db_manager_class = db_manager or self._db_orm_mapping["manager"]
         self.field_builder = self._db_orm_mapping["field_builder"]
         self.get_model_fields = self._db_orm_mapping["model_fields_getter"]
 
 
-_config: typing.Optional[Config] = None
+_config: Optional[Config] = None
 
 
 def get_global_config() -> Config:
-    assert _config is not None, "Looks like you didn't call `setup_rest_framework(app)`"
+    err_msg = "Looks like you didn't call `setup_rest_framework(app)`"
+    assert _config, err_msg
     return _config
 
 
